@@ -1,4 +1,4 @@
-__version__ = '1.1.3'
+__version__ = '1.1.4'
 
 import requests
 import json
@@ -53,8 +53,8 @@ class StreamBot:
       if self.config.user is not None:
         req_body['user'] = self.config.user
 
-      if self.verbosity >= 3:
-        print(f"Current Request Body: {req_body}")
+      if self.verbosity >= 1:
+        print(f"STREAMBOT: Current Request Body: {req_body}")
       
       return req_body
 
@@ -111,6 +111,8 @@ class StreamBot:
       try:
           # Fire off conversation message array to OpenAI  
           response = requests.post(self.openai_url, stream=True, headers=reqHeaders, json=reqBody)
+          if self.verbosity >= 1:
+            print(response)
           # Using the Server Sent Events library to support "Stream" of tokens to simulate the AI typing out
           client = sseclient.SSEClient(response)
           # Array to capture the tokens since `response` will no longer be consumable
@@ -125,4 +127,5 @@ class StreamBot:
               except json.decoder.JSONDecodeError:
                   pass
       except requests.exceptions.RequestException as e:
+        if self.verbosity >= 1:
           print(f"An error occurred: {e}")
\ No newline at end of file
